==> vcd-cli-20.1.2.dev10.tar.gz: vcd-cli-20.1.2.dev10/docs/commands.md <==
<div class="clt">
<ul><li>
<a href="vcd">vcd</a><ul><li>
<a href="vcd_catalog">catalog</a><ul><li>
<a href="vcd_catalog_acl">acl</a><ul><li>
<a href="vcd_catalog_acl_add">add</a></li><li>
<a href="vcd_catalog_acl_list">list</a></li><li>
<a href="vcd_catalog_acl_remove">remove</a></li><li>
<a href="vcd_catalog_acl_share">share</a></li><li>
<a href="vcd_catalog_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_catalog_change-owner">change-owner</a></li><li>
<a href="vcd_catalog_create">create</a></li><li>
<a href="vcd_catalog_delete">delete</a></li><li>
<a href="vcd_catalog_download">download</a></li><li>
<a href="vcd_catalog_info">info</a></li><li>
<a href="vcd_catalog_list">list</a></li><li>
<a href="vcd_catalog_share">share</a></li><li>
<a href="vcd_catalog_unshare">unshare</a></li><li>
<a href="vcd_catalog_update">update</a></li><li>
<a href="vcd_catalog_upload">upload</a></li>
</ul></li>
<li>
<a href="vcd_disk">disk</a><ul><li>
<a href="vcd_disk_change-owner">change-owner</a></li><li>
<a href="vcd_disk_create">create</a></li><li>
<a href="vcd_disk_delete">delete</a></li><li>
<a href="vcd_disk_info">info</a></li><li>
<a href="vcd_disk_list">list</a></li><li>
<a href="vcd_disk_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway">gateway</a><ul><li>
<a href="vcd_gateway_list">list</a></li>
</ul></li>
<li>
<a href="vcd_help">help</a></li><li>
<a href="vcd_info">info</a></li><li>
<a href="vcd_login">login</a></li><li>
<a href="vcd_logout">logout</a></li><li>
<a href="vcd_netpool">netpool</a><ul><li>
<a href="vcd_netpool_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network">network</a><ul><li>
<a href="vcd_network_direct">direct</a><ul><li>
<a href="vcd_network_direct_create">create</a></li><li>
<a href="vcd_network_direct_delete">delete</a></li><li>
<a href="vcd_network_direct_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network_external">external</a><ul><li>
<a href="vcd_network_external_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network_isolated">isolated</a><ul><li>
<a href="vcd_network_isolated_create">create</a></li><li>
<a href="vcd_network_isolated_delete">delete</a></li><li>
<a href="vcd_network_isolated_list">list</a></li>
</ul></li>
</ul></li>
<li>
<a href="vcd_org">org</a><ul><li>
<a href="vcd_org_create">create</a></li><li>
<a href="vcd_org_delete">delete</a></li><li>
<a href="vcd_org_info">info</a></li><li>
<a href="vcd_org_list">list</a></li><li>
<a href="vcd_org_update">update</a></li><li>
<a href="vcd_org_use">use</a></li>
</ul></li>
<li>
<a href="vcd_profile">profile</a></li><li>
<a href="vcd_pvdc">pvdc</a><ul><li>
<a href="vcd_pvdc_info">info</a></li><li>
<a href="vcd_pvdc_list">list</a></li>
</ul></li>
<li>
<a href="vcd_pwd">pwd</a></li><li>
<a href="vcd_right">right</a><ul><li>
<a href="vcd_right_add">add</a></li><li>
<a href="vcd_right_info">info</a></li><li>
<a href="vcd_right_list">list</a></li><li>
<a href="vcd_right_remove">remove</a></li>
</ul></li>
<li>
<a href="vcd_role">role</a><ul><li>
<a href="vcd_role_add-right">add-right</a></li><li>
<a href="vcd_role_create">create</a></li><li>
<a href="vcd_role_delete">delete</a></li><li>
<a href="vcd_role_info">info</a></li><li>
<a href="vcd_role_link">link</a></li><li>
<a href="vcd_role_list">list</a></li><li>
<a href="vcd_role_list-rights">list-rights</a></li><li>
<a href="vcd_role_remove-right">remove-right</a></li><li>
<a href="vcd_role_unlink">unlink</a></li>
</ul></li>
<li>
<a href="vcd_search">search</a></li><li>
<a href="vcd_system">system</a><ul><li>
<a href="vcd_system_amqp">amqp</a><ul><li>
<a href="vcd_system_amqp_info">info</a></li><li>
<a href="vcd_system_amqp_set">set</a></li><li>
<a href="vcd_system_amqp_test">test</a></li>
</ul></li>
<li>
<a href="vcd_system_extension">extension</a><ul><li>
<a href="vcd_system_extension_create">create</a></li><li>
<a href="vcd_system_extension_delete">delete</a></li><li>
<a href="vcd_system_extension_info">info</a></li><li>
<a href="vcd_system_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_system_info">info</a></li>
</ul></li>
<li>
<a href="vcd_task">task</a><ul><li>
<a href="vcd_task_info">info</a></li><li>
<a href="vcd_task_list">list</a></li><li>
<a href="vcd_task_update">update</a></li><li>
<a href="vcd_task_wait">wait</a></li>
</ul></li>
<li>
<a href="vcd_user">user</a><ul><li>
<a href="vcd_user_create">create</a></li><li>
<a href="vcd_user_delete">delete</a></li><li>
<a href="vcd_user_update">update</a></li>
</ul></li>
<li>
<a href="vcd_vapp">vapp</a><ul><li>
<a href="vcd_vapp_acl">acl</a><ul><li>
<a href="vcd_vapp_acl_add">add</a></li><li>
<a href="vcd_vapp_acl_list">list</a></li><li>
<a href="vcd_vapp_acl_remove">remove</a></li><li>
<a href="vcd_vapp_acl_share">share</a></li><li>
<a href="vcd_vapp_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_vapp_add-disk">add-disk</a></li><li>
<a href="vcd_vapp_add-vm">add-vm</a></li><li>
<a href="vcd_vapp_attach">attach</a></li><li>
<a href="vcd_vapp_capture">capture</a></li><li>
<a href="vcd_vapp_change-owner">change-owner</a></li><li>
<a href="vcd_vapp_connect">connect</a></li><li>
<a href="vcd_vapp_create">create</a></li><li>
<a href="vcd_vapp_delete">delete</a></li><li>
<a href="vcd_vapp_deploy">deploy</a></li><li>
<a href="vcd_vapp_detach">detach</a></li><li>
<a href="vcd_vapp_disconnect">disconnect</a></li><li>
<a href="vcd_vapp_info">info</a></li><li>
<a href="vcd_vapp_list">list</a></li><li>
<a href="vcd_vapp_power-off">power-off</a></li><li>
<a href="vcd_vapp_power-on">power-on</a></li><li>
<a href="vcd_vapp_reboot">reboot</a></li><li>
<a href="vcd_vapp_reset">reset</a></li><li>
<a href="vcd_vapp_shutdown">shutdown</a></li><li>
<a href="vcd_vapp_undeploy">undeploy</a></li><li>
<a href="vcd_vapp_update-lease">update-lease</a></li><li>
<a href="vcd_vapp_use">use</a></li>
</ul></li>
<li>
<a href="vcd_vc">vc</a><ul><li>
<a href="vcd_vc_info">info</a></li><li>
<a href="vcd_vc_list">list</a></li>
</ul></li>
<li>
<a href="vcd_vdc">vdc</a><ul><li>
<a href="vcd_vdc_acl">acl</a><ul><li>
<a href="vcd_vdc_acl_add">add</a></li><li>
<a href="vcd_vdc_acl_list">list</a></li><li>
<a href="vcd_vdc_acl_remove">remove</a></li><li>
<a href="vcd_vdc_acl_share">share</a></li><li>
<a href="vcd_vdc_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_vdc_create">create</a></li><li>
<a href="vcd_vdc_delete">delete</a></li><li>
<a href="vcd_vdc_disable">disable</a></li><li>
<a href="vcd_vdc_enable">enable</a></li><li>
<a href="vcd_vdc_info">info</a></li><li>
<a href="vcd_vdc_list">list</a></li><li>
<a href="vcd_vdc_use">use</a></li>
</ul></li>
<li>
<a href="vcd_version">version</a></li><li>
<a href="vcd_vm">vm</a><ul><li>
<a href="vcd_vm_info">info</a></li><li>
<a href="vcd_vm_list">list</a></li></ul>
</li></ul>
</li></ul>
</div>

==> vcd-cli-20.1.3.dev13.tar.gz: vcd-cli-20.1.3.dev13/docs/commands.md <==
<div class="clt">
<ul><li>
<a href="vcd">vcd</a><ul><li>
<a href="vcd_catalog">catalog</a><ul><li>
<a href="vcd_catalog_acl">acl</a><ul><li>
<a href="vcd_catalog_acl_add">add</a></li><li>
<a href="vcd_catalog_acl_list">list</a></li><li>
<a href="vcd_catalog_acl_remove">remove</a></li><li>
<a href="vcd_catalog_acl_share">share</a></li><li>
<a href="vcd_catalog_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_catalog_change-owner">change-owner</a></li><li>
<a href="vcd_catalog_create">create</a></li><li>
<a href="vcd_catalog_delete">delete</a></li><li>
<a href="vcd_catalog_download">download</a></li><li>
<a href="vcd_catalog_info">info</a></li><li>
<a href="vcd_catalog_list">list</a></li><li>
<a href="vcd_catalog_share">share</a></li><li>
<a href="vcd_catalog_unshare">unshare</a></li><li>
<a href="vcd_catalog_update">update</a></li><li>
<a href="vcd_catalog_upload">upload</a></li>
</ul></li>
<li>
<a href="vcd_cse">cse</a><ul><li>
<a href="vcd_cse_cluster">cluster</a><ul><li>
<a href="vcd_cse_cluster_config">config</a></li><li>
<a href="vcd_cse_cluster_create">create</a></li><li>
<a href="vcd_cse_cluster_delete">delete</a></li><li>
<a href="vcd_cse_cluster_info">info</a></li><li>
<a href="vcd_cse_cluster_list">list</a></li>
</ul></li>
<li>
<a href="vcd_cse_node">node</a><ul><li>
<a href="vcd_cse_node_create">create</a></li><li>
<a href="vcd_cse_node_delete">delete</a></li><li>
<a href="vcd_cse_node_list">list</a></li>
</ul></li>
<li>
<a href="vcd_cse_system">system</a><ul><li>
<a href="vcd_cse_system_disable">disable</a></li><li>
<a href="vcd_cse_system_enable">enable</a></li><li>
<a href="vcd_cse_system_info">info</a></li><li>
<a href="vcd_cse_system_stop">stop</a></li>
</ul></li>
<li>
<a href="vcd_cse_template">template</a><ul><li>
<a href="vcd_cse_template_list">list</a></li>
</ul></li>
<li>
<a href="vcd_cse_version">version</a></li>
</ul></li>
<li>
<a href="vcd_disk">disk</a><ul><li>
<a href="vcd_disk_change-owner">change-owner</a></li><li>
<a href="vcd_disk_create">create</a></li><li>
<a href="vcd_disk_delete">delete</a></li><li>
<a href="vcd_disk_info">info</a></li><li>
<a href="vcd_disk_list">list</a></li><li>
<a href="vcd_disk_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway">gateway</a><ul><li>
<a href="vcd_gateway_list">list</a></li>
</ul></li>
<li>
<a href="vcd_help">help</a></li><li>
<a href="vcd_info">info</a></li><li>
<a href="vcd_login">login</a></li><li>
<a href="vcd_logout">logout</a></li><li>
<a href="vcd_netpool">netpool</a><ul><li>
<a href="vcd_netpool_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network">network</a><ul><li>
<a href="vcd_network_direct">direct</a><ul><li>
<a href="vcd_network_direct_create">create</a></li><li>
<a href="vcd_network_direct_delete">delete</a></li><li>
<a href="vcd_network_direct_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network_external">external</a><ul><li>
<a href="vcd_network_external_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network_isolated">isolated</a><ul><li>
<a href="vcd_network_isolated_create">create</a></li><li>
<a href="vcd_network_isolated_delete">delete</a></li><li>
<a href="vcd_network_isolated_list">list</a></li>
</ul></li>
</ul></li>
<li>
<a href="vcd_org">org</a><ul><li>
<a href="vcd_org_create">create</a></li><li>
<a href="vcd_org_delete">delete</a></li><li>
<a href="vcd_org_info">info</a></li><li>
<a href="vcd_org_list">list</a></li><li>
<a href="vcd_org_update">update</a></li><li>
<a href="vcd_org_use">use</a></li>
</ul></li>
<li>
<a href="vcd_profile">profile</a><ul><li>
<a href="vcd_profile_extension">extension</a><ul><li>
<a href="vcd_profile_extension_add">add</a></li><li>
<a href="vcd_profile_extension_delete">delete</a></li><li>
<a href="vcd_profile_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_profile_info">info</a></li>
</ul></li>
<li>
<a href="vcd_pvdc">pvdc</a><ul><li>
<a href="vcd_pvdc_create">create</a></li><li>
<a href="vcd_pvdc_info">info</a></li><li>
<a href="vcd_pvdc_list">list</a></li>
</ul></li>
<li>
<a href="vcd_pwd">pwd</a></li><li>
<a href="vcd_right">right</a><ul><li>
<a href="vcd_right_add">add</a></li><li>
<a href="vcd_right_info">info</a></li><li>
<a href="vcd_right_list">list</a></li><li>
<a href="vcd_right_remove">remove</a></li>
</ul></li>
<li>
<a href="vcd_role">role</a><ul><li>
<a href="vcd_role_add-right">add-right</a></li><li>
<a href="vcd_role_create">create</a></li><li>
<a href="vcd_role_delete">delete</a></li><li>
<a href="vcd_role_info">info</a></li><li>
<a href="vcd_role_link">link</a></li><li>
<a href="vcd_role_list">list</a></li><li>
<a href="vcd_role_list-rights">list-rights</a></li><li>
<a href="vcd_role_remove-right">remove-right</a></li><li>
<a href="vcd_role_unlink">unlink</a></li>
</ul></li>
<li>
<a href="vcd_search">search</a></li><li>
<a href="vcd_system">system</a><ul><li>
<a href="vcd_system_amqp">amqp</a><ul><li>
<a href="vcd_system_amqp_info">info</a></li><li>
<a href="vcd_system_amqp_set">set</a></li><li>
<a href="vcd_system_amqp_test">test</a></li>
</ul></li>
<li>
<a href="vcd_system_extension">extension</a><ul><li>
<a href="vcd_system_extension_create">create</a></li><li>
<a href="vcd_system_extension_delete">delete</a></li><li>
<a href="vcd_system_extension_info">info</a></li><li>
<a href="vcd_system_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_system_info">info</a></li>
</ul></li>
<li>
<a href="vcd_task">task</a><ul><li>
<a href="vcd_task_info">info</a></li><li>
<a href="vcd_task_list">list</a></li><li>
<a href="vcd_task_update">update</a></li><li>
<a href="vcd_task_wait">wait</a></li>
</ul></li>
<li>
<a href="vcd_user">user</a><ul><li>
<a href="vcd_user_create">create</a></li><li>
<a href="vcd_user_delete">delete</a></li><li>
<a href="vcd_user_list">list</a></li><li>
<a href="vcd_user_update">update</a></li>
</ul></li>
<li>
<a href="vcd_vapp">vapp</a><ul><li>
<a href="vcd_vapp_acl">acl</a><ul><li>
<a href="vcd_vapp_acl_add">add</a></li><li>
<a href="vcd_vapp_acl_list">list</a></li><li>
<a href="vcd_vapp_acl_remove">remove</a></li><li>
<a href="vcd_vapp_acl_share">share</a></li><li>
<a href="vcd_vapp_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_vapp_add-disk">add-disk</a></li><li>
<a href="vcd_vapp_add-vm">add-vm</a></li><li>
<a href="vcd_vapp_attach">attach</a></li><li>
<a href="vcd_vapp_capture">capture</a></li><li>
<a href="vcd_vapp_change-owner">change-owner</a></li><li>
<a href="vcd_vapp_connect">connect</a></li><li>
<a href="vcd_vapp_create">create</a></li><li>
<a href="vcd_vapp_delete">delete</a></li><li>
<a href="vcd_vapp_deploy">deploy</a></li><li>
<a href="vcd_vapp_detach">detach</a></li><li>
<a href="vcd_vapp_disconnect">disconnect</a></li><li>
<a href="vcd_vapp_info">info</a></li><li>
<a href="vcd_vapp_list">list</a></li><li>
<a href="vcd_vapp_power-off">power-off</a></li><li>
<a href="vcd_vapp_power-on">power-on</a></li><li>
<a href="vcd_vapp_reboot">reboot</a></li><li>
<a href="vcd_vapp_reset">reset</a></li><li>
<a href="vcd_vapp_shutdown">shutdown</a></li><li>
<a href="vcd_vapp_undeploy">undeploy</a></li><li>
<a href="vcd_vapp_update-lease">update-lease</a></li><li>
<a href="vcd_vapp_use">use</a></li>
</ul></li>
<li>
<a href="vcd_vc">vc</a><ul><li>
<a href="vcd_vc_info">info</a></li><li>
<a href="vcd_vc_list">list</a></li>
</ul></li>
<li>
<a href="vcd_vdc">vdc</a><ul><li>
<a href="vcd_vdc_acl">acl</a><ul><li>
<a href="vcd_vdc_acl_add">add</a></li><li>
<a href="vcd_vdc_acl_list">list</a></li><li>
<a href="vcd_vdc_acl_remove">remove</a></li><li>
<a href="vcd_vdc_acl_share">share</a></li><li>
<a href="vcd_vdc_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_vdc_create">create</a></li><li>
<a href="vcd_vdc_delete">delete</a></li><li>
<a href="vcd_vdc_disable">disable</a></li><li>
<a href="vcd_vdc_enable">enable</a></li><li>
<a href="vcd_vdc_info">info</a></li><li>
<a href="vcd_vdc_list">list</a></li><li>
<a href="vcd_vdc_use">use</a></li>
</ul></li>
<li>
<a href="vcd_version">version</a></li><li>
<a href="vcd_vm">vm</a><ul><li>
<a href="vcd_vm_info">info</a></li><li>
<a href="vcd_vm_list">list</a></li><li>
<a href="vcd_vm_update">update</a></li></ul>
</li></ul>
</li></ul>
</div>
